#!/usr/bin/env python

"""
Access-control-related scheduling functionality.

Copyright (C) 2016 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.data import get_address

def same_domain_only(handler):

    """
    Attempt to schedule the current object of the given 'handler' if the
    organiser employs an address in the same domain as the resource.
    """

    organiser = get_address(handler.obj.get_value("ORGANIZER"))
    user = get_address(handler.user)

    organiser_domain = organiser.rsplit("@", 1)[-1]
    user_domain = user.rsplit("@", 1)[-1]
    
    return organiser_domain == user_domain and "ACCEPTED" or "DECLINED"

# Registry of scheduling functions.

scheduling_functions = {
    "same_domain_only" : same_domain_only,
    }

# vim: tabstop=4 expandtab shiftwidth=4
